vip\_hci.fm package
===================

Submodules
----------

vip\_hci.fm.fakecomp module
---------------------------

.. automodule:: vip_hci.fm.fakecomp
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.fm.fakedisk module
---------------------------

.. automodule:: vip_hci.fm.fakedisk
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.fm.negfc\_fmerit module
--------------------------------

.. automodule:: vip_hci.fm.negfc_fmerit
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.fm.negfc\_mcmc module
------------------------------

.. automodule:: vip_hci.fm.negfc_mcmc
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.fm.negfc\_nested module
--------------------------------

.. automodule:: vip_hci.fm.negfc_nested
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.fm.negfc\_simplex module
---------------------------------

.. automodule:: vip_hci.fm.negfc_simplex
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.fm.negfc\_speckle\_noise module
----------------------------------------

.. automodule:: vip_hci.fm.negfc_speckle_noise
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.fm.negfd\_fmerit module
--------------------------------

.. automodule:: vip_hci.fm.negfd_fmerit
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.fm.negfd\_interp module
--------------------------------

.. automodule:: vip_hci.fm.negfd_interp
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.fm.negfd\_simplex module
---------------------------------

.. automodule:: vip_hci.fm.negfd_simplex
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.fm.scattered\_light\_disk module
-----------------------------------------

.. automodule:: vip_hci.fm.scattered_light_disk
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.fm.utils\_mcmc module
------------------------------

.. automodule:: vip_hci.fm.utils_mcmc
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.fm.utils\_negfc module
-------------------------------

.. automodule:: vip_hci.fm.utils_negfc
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.fm.utils\_negfd module
-------------------------------

.. automodule:: vip_hci.fm.utils_negfd
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: vip_hci.fm
   :members:
   :undoc-members:
   :show-inheritance:
